@@ -186,9 +186,7 @@ def volume(freq, psd, z_hor=None, detection_snr=DETECTION_SNR, H=None, **params)
     # create a Gauss-Legendre quadrature for the integration:
     # https://en.wikipedia.org/wiki/Gaussian_quadrature#Gauss.E2.80.93Legendre_quadrature
     # x are the roots and w are the weights
-    x, w = scipy.special.orthogonal.p_roots(20)
-    # older versions of p_roots return complex roots
-    x = np.real(x)
+    x, w = scipy.special.p_roots(20)
     # account for the fact that the interval is [0,z_hor], not [-1,1]
     z = 0.5 * z_hor * (x + 1.0)
 
